BackgroundTaskViewState

Struct BackgroundTaskViewState 

pub struct BackgroundTaskViewState {
    pub tasks: HashMap<String, BackgroundTaskView>,
    pub synced_at_ms: Option<u64>,
}
Lightweight cached task view stored on the owner thread for prompt injection. The canonical task state remains in the task thread.

Fields

tasks: HashMap<String, BackgroundTaskView>synced_at_ms: Option<u64>